package org.apache.commons.lang3.concurrent;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.util.concurrent.Executors;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.atomic.AtomicLong;

public class BasicThreadFactory implements ThreadFactory {
  private final AtomicLong threadCounter;
  
  private final ThreadFactory wrappedFactory;
  
  private final Thread.UncaughtExceptionHandler uncaughtExceptionHandler;
  
  private final String namingPattern;
  
  private final Integer priority;
  
  private final Boolean daemon;
  
  private BasicThreadFactory(Builder builder) {
    if (Builder.access$000(builder) == null) {
      this.wrappedFactory = Executors.defaultThreadFactory();
    } else {
      this.wrappedFactory = Builder.access$000(builder);
    } 
    this.namingPattern = Builder.access$100(builder);
    this.priority = Builder.access$200(builder);
    this.daemon = Builder.access$300(builder);
    this.uncaughtExceptionHandler = Builder.access$400(builder);
    this.threadCounter = new AtomicLong();
  }
  
  public final ThreadFactory getWrappedFactory() {
    return this.wrappedFactory;
  }
  
  public final String getNamingPattern() {
    return this.namingPattern;
  }
  
  public final Boolean getDaemonFlag() {
    return this.daemon;
  }
  
  public final Integer getPriority() {
    return this.priority;
  }
  
  public final Thread.UncaughtExceptionHandler getUncaughtExceptionHandler() {
    return this.uncaughtExceptionHandler;
  }
  
  public long getThreadCount() {
    return this.threadCounter.get();
  }
  
  public Thread newThread(Runnable runnable) {
    Thread thread = getWrappedFactory().newThread(runnable);
    initializeThread(thread);
    return thread;
  }
  
  private void initializeThread(Thread thread) {
    if (getNamingPattern() != null) {
      Long count = Long.valueOf(this.threadCounter.incrementAndGet());
      thread.setName(String.format(getNamingPattern(), new Object[] { count }));
    } 
    if (getUncaughtExceptionHandler() != null)
      thread.setUncaughtExceptionHandler(getUncaughtExceptionHandler()); 
    if (getPriority() != null)
      thread.setPriority(getPriority().intValue()); 
    if (getDaemonFlag() != null)
      thread.setDaemon(getDaemonFlag().booleanValue()); 
  }
}
